@@ -53,6 +53,13 @@ impl PublicKeySet {
             );
             return Err(WSError::ParseError);
         }
+        if signature_data.content_type != SIGNATURE_WASM_MODULE_CONTENT_TYPE {
+            debug!(
+                "Unsupported content type: {:02x}",
+                signature_data.content_type,
+            );
+            return Err(WSError::ParseError);
+        }
 
         let signed_hashes_set = signature_data.signed_hashes_set;
         let mut valid_hashes_for_pks = HashMap::new();
